@@ -150,13 +150,13 @@ def run(label):
     logs = sort_(logs, "i*", cont)
     if len(logs) == 0:
         run_next("1", label)
-    elif len(folders) != len(logs) != 0 or folders[-1] != logs[-1].rsplit(os.sep)[0] + os.sep:
+    else:
         with open(logs[-1], "r") as file:
             lines = file.readlines()
             if lines[-1] == "Job completed\n":
                 print(f"{logs[-1]}: Job completed")
-                if not os.path.isfile(
-                        f"{cwd}{os.sep}i" + str(int(logs[-1].split(os.sep)[0].strip("i")) + 1) + os.sep + label + ".fdf"
+                if len(folders) != len(logs) and not os.path.isfile(
+                        f"{cwd}{os.sep}i{str(int(logs[-1].split(os.sep)[0].strip('i')) + 1)}{os.sep}{label}.fdf"
                 ):
                     if cont in logs[-1]:
                         match = re.search(f"i([0-9]+){os.sep}{cont}(_*[0-9]*)", logs[-1])
@@ -172,17 +172,21 @@ def run(label):
                             "i" + str(int(logs[-1].split(os.sep)[0].strip("i")) + 1) + os.sep + label + ".fdf"
                         )
                 file.close()
-                run_next(str(int(logs[-1].split(os.sep)[0].strip("i")) + 1), label)
+                if len(folders) > len(logs) + 1:
+                    run_next(str(int(logs[-1].split(os.sep)[0].strip("i")) + 1), label)
             elif not run_interrupted(str(int(logs[-1].split(os.sep)[0].strip("i"))), label):
                 run_next(str(int(logs[-1].split(os.sep)[0].strip("i")) + 1), label)
     print("All iterations are completed")
     if conda:
-        sprun(["conda", "deactivate"])
+        sprun(
+            [f"{os.sep}usr{os.sep}bin{os.sep}conda", "deactivate"] if os.name == "posix"
+            else [f"C:{os.sep}{os.sep}Anaconda3{os.sep}Scripts{os.sep}deactivate"]
+        )
 
 
 def run_interrupted(i, label):
     """Continue to an interrupted calculation"""
-    folders = glob.glob(f"i*{os.sep}{cont}*")
+    folders = glob.glob(f"i{i}{os.sep}{cont}*")
     folders = sort_(folders, "i*", cont)
     if len(folders) != 0:
         with open(f"{folders[-1]}{os.sep}{log}") as file:
@@ -238,7 +242,7 @@ def copy_files(extensions, label, source_, destination):
                 for f in files:
                     file = f.split(os.sep)[-1]
                     copy_file(f, f"{destination}{os.sep}{file}")
-            if ext == "ion":
+            elif ext == "ion":
                 files = glob.glob(f"{source_}{os.sep}*.ion")
                 for f in files:
                     file = f.split(os.sep)[-1]
@@ -290,7 +294,8 @@ def energy_diff(path=None):
 def _command(label=None, issingle=False):
     """SIESTA's run command"""
     if conda:
-        sprun(["conda", "activate", conda])
+        sprun([f"{os.sep}usr{os.sep}bin{os.sep}conda", "activate", conda] if os.name == "posix"
+              else [f"C:{os.sep}{os.sep}Anaconda3{os.sep}Scripts{os.sep}activate", conda])
     with open(log, "w") as logger:
         job = Popen(
             shlex.split(f"{f'mpirun -np {cores} ' if cores is not None else ''}{siesta} {label}.fdf"),
@@ -356,4 +361,4 @@ def update_cont(newcont):
 
 def update_siesta(newsiesta):
     global siesta
-    siesta = newsiesta
\ No newline at end of file
+    siesta = newsiesta
